/*
A copyright statement is attached to every file and product created for the
project.  It takes the form of the copyright statement for this 
document:

The project provides a modern way to design and knit garments
using domestic and semi-professional knitting machines.  This document
describes the LockController hardware.

Copyright (C) 2020 Owen Mace

This document is free information: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <https://www.gnu.org/licenses/>.
*/

//Box component of a Container for Lock Controller - 14 March 2020

include <LC_Constants.scad>

//Draw the container
color( BoxColour)
//Shows the level of the PCB. Comment out for production
//translate([ -( ContainerXmm + 10) / 2, -( ContainerYmm - 10) / 2, ScrewPostZmm + ContainerTmm]) #cube([ ContainerXmm + 10, ContainerYmm, PCBT]);

difference()
{
  union()
  {
    difference()
    {
      translate([ 0, 0, ContainerZmm / 2])
        cube([ ContainerXmm, ContainerYmm, ContainerZmm], center=true);
    //Remove the inside of the container
      translate([0, 0, ContainerZmm / 2 + ContainerTmm])
        cube([ ContainerXmm - ContainerTmm * 2,
               ContainerYmm - ContainerTmm * 2,
               ContainerZmm], center=true);
    //Remove the center mounting hole
      translate([ 0, 0, -ContainerTmm])
        cylinder( ContainerTmm * 4, HoleDmm / 2, HoleDmm / 2);
    //Remove holes for alignment plate
      for ( i = [ -ContainerXmm / 4: ContainerXmm / 2: ContainerXmm / 4])
      {
        translate([  i, 0, -ContainerTmm])
          cylinder( ContainerZmm, ScrewPostRmm, ScrewPostRmm);
      }
    //Remove ventillation holes
      HoleX = ContainerXmm / 4;
      for ( i = [ -HoleX: HoleX: HoleX])
      {
        translate([ i, -ContainerYmm / 2, ContainerZmm / 2])
        rotate([ 90, 0, 0])
          cylinder( ContainerZmm, r = VentHoleRmm * 2, center = true);
      }
    //Remove holes in front panel
      OffsetXYZ = [ -PCBXmm / 2, PCBYmm / 2, ContainerTmm + ScrewPostZmm + PCBZ];
      translate( LED_Orange + OffsetXYZ)  rotate([ -90, 0, 0])
        cylinder( ContainerZmm, d = LED_Orange_d);
      translate( Nano + OffsetXYZ)        rotate([ -90, 0, 0])
        cylinder( ContainerZmm, d = Nano_d);
      translate( Barrel_Jack + OffsetXYZ) rotate([ -90, 0, 0])
        cylinder( ContainerZmm, d = Barrel_Jack_d);
      translate( LED_Red + OffsetXYZ)     rotate([ -90, 0, 0])
        cylinder( ContainerZmm, d = LED_Red_d);
      translate( DIN6 + OffsetXYZ)        rotate([ -90, 0, 0])
        cylinder( ContainerZmm, d = DIN6_d);
      //Slot above DIN6
      translate([ -DIN6_d / 2, ContainerTmm / 2 - Tolerancemm, 0])
      translate( DIN6 + OffsetXYZ)
        cube([ DIN6_d, ContainerTmm + Tolerancemm * 2, DIN6_d * 2]);
    //Remove holes in side panel
      translate( OffsetXYZ - RJ45) translate([ -RJ45_y_z / 2, -RJ45_y_z / 2, 0])
        cube([ RJ45_y_z, RJ45_y_z, RJ45_y_z]);
      translate( OffsetXYZ - AudioJack5)  rotate([ 0, -90, 0])
        cylinder( 15, d = AudioJack5_d);
      translate( OffsetXYZ - AudioJack6)  rotate([ 0, -90, 0])
        cylinder( 15, d = AudioJack6_d);
    }
    //Add the mounting posts for the PCB
    XPost = PCBXmm / 2 - ScrewPostOmm;
    YPost = PCBYmm / 2 - ScrewPostOmm;
    translate([  XPost,  YPost, ContainerTmm])
      cylinder( ScrewPostZmm, ScrewPostRmm, ScrewPostRmm);
    translate([  XPost, -YPost, ContainerTmm])
      cylinder( ScrewPostZmm, ScrewPostRmm, ScrewPostRmm);
    translate([ -XPost,  YPost, ContainerTmm])
      cylinder( ScrewPostZmm, ScrewPostRmm, ScrewPostRmm);
    translate([ -XPost, -YPost, ContainerTmm])
      cylinder( ScrewPostZmm, ScrewPostRmm, ScrewPostRmm);
    //Add the lid screw posts
    PostZ       = ContainerZmm;
    PostZOffset = ContainerZmm - PostZ;
    translate([  XLid,  YLid, PostZOffset]) cylinder( PostZ, 0, LidPostRmm);
    translate([  XLid, -YLid, PostZOffset]) cylinder( PostZ, 0, LidPostRmm);
    translate([ -XLid,  YLid, PostZOffset]) cylinder( PostZ, 0, LidPostRmm);
    translate([ -XLid, -YLid, PostZOffset]) cylinder( PostZ, 0, LidPostRmm);
    //Add labels for E3000 motor connections
    TextT = 1.0;
    LabelsOffset = [ -PCBXmm / 2 - ContainerTmm - 1.0,
                      PCBYmm / 2 + ContainerTmm + TextT,
                      ContainerTmm + ScrewPostZmm + PCBZ * 3 + AudioJack6_d / 2];
    translate( LabelsOffset - AudioJack5)
    rotate([ 0, 0, -90]) rotate([ 90, 0, 0])
    linear_extrude( height = TextT)
      #text( "A", size = 6);
    translate( LabelsOffset - AudioJack6)
    rotate([ 0, 0, -90]) rotate([ 90, 0, 0])
    linear_extrude( height = TextT)
      #text( "C", size = 6);
  }
  //Remove the screw holes from the lid screw posts
  translate([  XLid,  YLid, ContainerZmm / 2 + 13.7])
    cylinder( ContainerZmm / 2, ScrewHoleRmm, ScrewHoleRmm, center = true);
  translate([  XLid, -YLid, ContainerZmm / 2 + 13.7])
    cylinder( ContainerZmm / 2, ScrewHoleRmm, ScrewHoleRmm, center = true);
  translate([ -XLid,  YLid, ContainerZmm / 2 + 13.7])
    cylinder( ContainerZmm / 2, ScrewHoleRmm, ScrewHoleRmm, center = true);
  translate([ -XLid, -YLid, ContainerZmm / 2 + 13.7])
    cylinder( ContainerZmm / 2, ScrewHoleRmm, ScrewHoleRmm, center = true);
  //Remove the screw post holes
  XPost = PCBXmm / 2 - ScrewPostOmm;
  YPost = PCBYmm / 2 - ScrewPostOmm;
  translate([  XPost,  YPost, ContainerTmm])
   cylinder( ScrewPostZmm + Tolerancemm, ScrewHoleRmm, ScrewHoleRmm);
  translate([  XPost, -YPost, ContainerTmm])
    cylinder( ScrewPostZmm + Tolerancemm, ScrewHoleRmm, ScrewHoleRmm);
  translate([ -XPost,  YPost, ContainerTmm])
     cylinder( ScrewPostZmm + Tolerancemm, ScrewHoleRmm, ScrewHoleRmm);
  translate([ -XPost, -YPost, ContainerTmm])
    cylinder( ScrewPostZmm + Tolerancemm, ScrewHoleRmm, ScrewHoleRmm);
}
