/*
A copyright statement is attached to every file and product created for the
project.  It takes the form of the copyright statement for this 
document:

The project provides a modern way to design and knit garments
using domestic and semi-professional knitting machines.  This document
describes the LockController hardware.

Copyright (C) 2020 Owen Mace

This document is free information: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Lid component of a Container for Lock Controller V16

include <LC_Constants.scad>

//Lid - 14 March 2020
difference()
{
  union()
  {
    cube([ ContainerXmm, ContainerYmm, ContainerTmm], center = true);
    translate([  XLid,  YLid, -ContainerTmm / 2])
      cylinder( ContainerTmm, r = LidPostRmm);
    translate([  XLid, -YLid, -ContainerTmm / 2])
      cylinder( ContainerTmm, r = LidPostRmm);
    translate([ -XLid,  YLid, -ContainerTmm / 2])
      cylinder( ContainerTmm, r = LidPostRmm);
    translate([ -XLid, -YLid, -ContainerTmm / 2])
      cylinder( ContainerTmm, r = LidPostRmm);
    //Text
    translate([ -XLid * 0.5,  5, ContainerTmm / 2])
    linear_extrude( height = 0.5)
      text( "Owen's Lock", size = 6);
    translate([ -XLid * 0.55, -5, ContainerTmm / 2])
    linear_extrude( height = 0.5)
      text( "Controller V16", size = 6);
  }
  //Remove four screw holes
  translate([  XLid,  YLid, -ContainerTmm])
    cylinder( ContainerTmm * 4, r = ScrewHoleRmm + Tolerancemm * 2, center = true);
  translate([  XLid, -YLid, -ContainerTmm])
    cylinder( ContainerTmm * 4, r = ScrewHoleRmm + Tolerancemm * 2, center = true);
  translate([ -XLid,  YLid, -ContainerTmm])
    cylinder( ContainerTmm * 4, r = ScrewHoleRmm + Tolerancemm * 2, center = true);
  translate([ -XLid, -YLid, -ContainerTmm])
    cylinder( ContainerTmm * 4, r = ScrewHoleRmm + Tolerancemm * 2, center = true);
  //Slot above DIN6
  OffsetXYZ = [ -PCBXmm / 2, PCBYmm / 2, ContainerTmm + ScrewPostZmm + PCBZ];
  translate([ -DIN6_d / 2, ContainerTmm / 2 - Tolerancemm, -DIN6_d * 2])
  translate( DIN6 + OffsetXYZ)
    cube([ DIN6_d, ContainerTmm + Tolerancemm * 2, DIN6_d * 2]);
}

