/*
A copyright statement is attached to every file and product created for the
project.  It takes the form of the copyright statement for this 
document:

The project provides a modern way to design and knit garments
using domestic and semi-professional knitting machines.  This document
describes the LockController hardware.

Copyright (C) 2020 Owen Mace

This document is free information: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Retainer component of a Container for Lock Controller V16

include <LC_Constants.scad>

//Retainer
difference()
{
  union()
  {
    cube([ RetainerXmm, RetainerYmm, RetainerTmm], center = true);
    translate([ 0, 0, -RetainerTmm / 2])
      cylinder( h = RetainerTmm, d = RetainerTmm * 3, center = true);
  }
  translate([ 0, 0, -RetainerTmm]) //Screw hole
    cylinder( RetainerTmm * 6, d = HoleDmm, center = true);
  NutRadius = Nutmm / 2 / cos( 180 / 6) + Tolerancemm * 2;
  translate([ 0, 0, -RetainerTmm / 2])
  rotate([ 0, 180, 0])
    cylinder(5, NutRadius, NutRadius, $fn=6);
}

//Add ridges at either end
  RidgeXmm = ( RetainerXmm - RetainerRidgeSepmm) / 2;
  translate([  RetainerXmm / 2 - RidgeXmm, -RetainerYmm / 2, RetainerTmm / 2])
    cube([ RidgeXmm, RetainerYmm, RetainerZmm]);
  translate([ -RetainerXmm / 2, -RetainerYmm / 2, RetainerTmm / 2])
    cube([ RidgeXmm, RetainerYmm, RetainerZmm]);
